@@ -18,7 +18,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import info
+from lfm import info
 
 
 VERSION     = info.VERSION
